import { __assign } from "tslib";
import React, { useState } from "react";
import { defaultStyle, getCommits, setBranchAndCommitColor, } from "../../helpers/utils";
import Branches from "../Branches";
import CommitDetails from "../CommitDetails";
import CommitDot from "../CommitDot";
import { getCommitDotPosition } from "../CommitDot/utils";
import Curves from "../Curves";
import { computePosition } from "./computePosition";
import css from "./index.module.css";
export default function CommitGraph(_a) {
    var commits = _a.commits, graphStyle = _a.graphStyle, branchHeads = _a.branchHeads;
    var _b = useState(false), showBlock = _b[0], setShowBlock = _b[1];
    var _c = useState(0), topPos = _c[0], setTopPos = _c[1];
    var commitNodes = getCommits(commits);
    var _d = __assign(__assign({}, defaultStyle), graphStyle), commitSpacing = _d.commitSpacing, branchSpacing = _d.branchSpacing, branchColors = _d.branchColors, nodeRadius = _d.nodeRadius;
    var _e = computePosition(commitNodes), columns = _e.columns, commitsMap = _e.commitsMap;
    var width = columns.length * (branchSpacing + nodeRadius * 2) + 3;
    // the position of the last commit is Math.max(...Array.from(commitsMap.values()).map((c) => c.x)), and 64 is the height of the commit details.
    var height = Math.max.apply(Math, Array.from(commitsMap.values()).map(function (c) { return c.x; })) * commitSpacing +
        nodeRadius * 8 +
        64;
    setBranchAndCommitColor(columns, branchColors, commitsMap);
    var commitsNodes = Array.from(commitsMap.values());
    var commitInfoLeftPosition = getCommitInfoLeftPosition(width);
    return (React.createElement("div", { className: css.container },
        React.createElement("div", { className: css.svg },
            React.createElement("svg", { width: width, height: height },
                React.createElement(Branches, { columns: columns, commitsMap: commitsMap, commitSpacing: commitSpacing, branchSpacing: branchSpacing, nodeRadius: nodeRadius, branchColors: branchColors }),
                React.createElement(Curves, { commitsMap: commitsMap, commits: commitsNodes, commitSpacing: commitSpacing, branchSpacing: branchSpacing, nodeRadius: nodeRadius }),
                commitsNodes.map(function (commit) {
                    return (React.createElement(CommitDot, { key: "".concat(commit.hash, "-dot"), commit: commit, commitSpacing: commitSpacing, branchSpacing: branchSpacing, nodeRadius: nodeRadius }));
                }))),
        React.createElement("div", { style: {
                left: commitInfoLeftPosition,
                width: "calc(100% - ".concat(commitInfoLeftPosition, "px)"),
            }, className: css.commitInfoContainer }, commitsNodes.map(function (commit) {
            var y = getCommitDotPosition(branchSpacing, commitSpacing, nodeRadius, commit).y;
            var branch = branchHeads.filter(function (b) { return b.headCommitHash === commit.hash; });
            var mouseOver = function () {
                setShowBlock(true);
                setTopPos(y);
            };
            var mouseLeave = function () {
                setShowBlock(false);
            };
            return (React.createElement("div", { style: { top: "calc(".concat(y, "px - 2rem)") }, className: css.details, key: "commit-details-".concat(commit.hash) },
                React.createElement(CommitDetails, { commit: commit, branch: branch, mouseOver: mouseOver, mouseLeave: mouseLeave })));
        })),
        showBlock && (React.createElement("div", { style: {
                left: -5,
                top: "calc(".concat(topPos, "px - 2rem)"),
                height: "4rem",
                width: "100%",
            }, className: css.block }))));
}
function getCommitInfoLeftPosition(width) {
    if (width < 250) {
        return 250;
    }
    if (width < 500) {
        return width + 10;
    }
    return 510;
}
//# sourceMappingURL=index.js.map