export function getMergedFromBranchHeadPositions(commit, commitsMap, branchSpacing, commitSpacing, nodeRadius) {
    if (commit.parents.length < 2) {
        return [];
    }
    var mergedFromBranchHeadPositions = [];
    for (var i = 1; i < commit.parents.length; i++) {
        var parent_1 = commitsMap.get(commit.parents[i]);
        if (parent_1) {
            var start = getPositionsBySpacing(branchSpacing, commitSpacing, nodeRadius, commit.x, commit.y);
            var endPoint = commit.x + 1 > parent_1.x ? parent_1.x : commit.x + 1;
            var height = Math.abs(parent_1.x - commit.x) * (commitSpacing + nodeRadius * 4);
            var width = Math.abs(parent_1.y - commit.y) * (branchSpacing + nodeRadius * 4);
            var end = getPositionsBySpacing(branchSpacing, commitSpacing, nodeRadius, endPoint, parent_1.y);
            mergedFromBranchHeadPositions.push({
                path: curvePath(start, end),
                stroke: parent_1.commitColor,
                id: "filter_".concat(commit.hash.slice(0, 7), "_curved_path_").concat(parent_1.hash.slice(0, 7)),
                x: start[0],
                y: start[1],
                width: width,
                height: height,
            });
        }
    }
    return mergedFromBranchHeadPositions;
}
export function getNewBranchToPath(commit, commitsMap, branchSpacing, commitSpacing, nodeRadius) {
    if (commit.children.length < 2) {
        return [];
    }
    var newBranchToPositions = [];
    commit.children.forEach(function (c) {
        var child = commitsMap.get(c);
        if (child.parents[0] === commit.hash && child.y !== commit.y) {
            var start = getPositionsBySpacing(branchSpacing, commitSpacing, nodeRadius, commit.x, commit.y);
            var endPoint = commit.x - 1 > child.x ? commit.x - 1 : child.x;
            var end = getPositionsBySpacing(branchSpacing, commitSpacing, nodeRadius, endPoint, child.y);
            var height = Math.abs(child.x - commit.x) * (commitSpacing + nodeRadius * 4);
            var width = Math.abs(child.y - commit.y) * (branchSpacing + nodeRadius * 4) + 4;
            newBranchToPositions.push({
                path: curvePath(start, [end[0], end[1] + nodeRadius * 2]),
                stroke: child.commitColor,
                id: "filter_".concat(commit.hash.slice(0, 7), "_curved_path_").concat(child.hash.slice(0, 7)),
                x: start[0],
                y: end[1],
                width: width,
                height: height,
            });
        }
    });
    return newBranchToPositions;
}
function curvePath(start, end) {
    var dx = (end[0] - start[0]) * 0.3;
    var dy = (start[1] - end[1]) * 0.4;
    var cx2 = end[0] - dx * 0.1;
    var cy2 = end[1] + dy;
    var cx1 = start[0] + dx * 3;
    var cy1 = start[1] - dy;
    return "M ".concat(start[0], " ").concat(start[1], " C ").concat(cx1, " ").concat(cy1, ", ").concat(cx2, " ").concat(cy2, ", ").concat(end[0], " ").concat(end[1]);
}
function getPositionsBySpacing(branchSpacing, commitSpacing, nodeRadius, x, y) {
    var realX = branchSpacing * y + nodeRadius * 4;
    var realY = commitSpacing * x + nodeRadius * 2;
    return [realX, realY];
}
export function excerpt(str, len) {
    return str.length > len ? str.substring(0, len) + "..." : str;
}
//# sourceMappingURL=utils.js.map