export var defaultStyle = {
    commitSpacing: 90,
    branchSpacing: 20,
    nodeRadius: 2,
    branchColors: [
        "#010A40",
        "#FC42C9",
        "#3D91F0",
        "#29E3C1",
        "#C5A15A",
        "#FA7978",
        "#5D6280",
        "#5AC58D",
        "#5C5AC5",
        "#EB7340",
    ],
};
export function getCommits(commits) {
    var childrenMap = new Map();
    commits.forEach(function (commit) {
        commit.parents.forEach(function (parent) {
            var _a;
            if (childrenMap.get(parent)) {
                (_a = childrenMap.get(parent)) === null || _a === void 0 ? void 0 : _a.push(commit.hash);
            }
            else {
                childrenMap.set(parent, [commit.hash]);
            }
        });
    });
    return commits.map(function (commit) {
        var _a;
        return {
            hash: commit.hash,
            parents: commit.parents,
            children: (_a = childrenMap.get(commit.hash)) !== null && _a !== void 0 ? _a : [],
            committer: commit.committer.displayName,
            message: commit.message,
            committerDate: new Date(commit.committedAt),
            commitLink: commit.commitLink,
            commitColor: "",
            x: -1,
            y: -1,
        };
    });
}
export function hexToColorMatrixVariant(hex) {
    if (!hex) {
        return "";
    }
    var r = parseInt(hex.substring(1, 3), 16) / 255;
    var g = parseInt(hex.substring(3, 5), 16) / 255;
    var b = parseInt(hex.substring(5, 7), 16) / 255;
    return "0 0 0 0 ".concat(r, " 0 0 0 0 ").concat(g, " 0 0 0 0 ").concat(b, " 0 0 0 0.5 0");
}
export function setCommitNodeColor(branch, columnNumber, commitsMap, branchColor) {
    commitsMap.forEach(function (commit) {
        if (commit.y === columnNumber &&
            branch.start <= commit.x &&
            branch.end >= commit.x) {
            commit.commitColor = branchColor;
        }
    });
}
export function setBranchAndCommitColor(columns, branchColors, commitsMap) {
    columns.map(function (column, i) {
        column.map(function (c) {
            var branchColor = branchColors[c.branchOrder % branchColors.length];
            c.color = branchColor;
            setCommitNodeColor(c, i, commitsMap, branchColor);
        });
    });
}
//# sourceMappingURL=utils.js.map